[![Build Status](https://travis-ci.org/ahartikainen/pyinfraformat.svg?branch=master)](https://travis-ci.org/ahartikainen/pyinfraformat) [![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black) [![Coverage Status](https://coveralls.io/repos/github/ahartikainen/pyinfraformat/badge.svg?branch=master)](https://coveralls.io/github/ahartikainen/pyinfraformat?branch=master)

# pyinfraformat
Python library for Finnish Infraformat (version 2.3)

## Installation

`pyinfraformat` can be installed with pip.

    python -m pip install pyinfraformat

#### Github version

`pyinfraformat` can be installed with pip (needs git-tools).

    python -m pip install git+https://github.com/ahartikainen/pyinfraformat

Library can be installed also by `git clone` / downloading zip.

    git clone https://github.com/ahartikainen/pyinfraformat
    cd pyinfraformat
    python -m pip install .

To install inplace for development work, use `-e` command.

    python -m pip install -e .
